@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2023 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2024 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -601,15 +601,15 @@ bool buildAdditionalPoints2D(GFace *gf)
             std::vector<double> t(blf->nb_divisions);
 
             double zlog = log((1 + blf->beta) / (blf->beta - 1));
-            printf("T = ");
+            // printf("T = ");
             for(int i = 0; i < blf->nb_divisions; i++) {
               const double eta = (double)(i + 1) / blf->nb_divisions;
               const double power = exp(zlog * (1. - eta));
               const double ratio = (1. - power) / (1. + power);
               t[i] = 1.0 + blf->beta * ratio;
-              printf("%12.5E ", t[i]);
+              // printf("%12.5E ", t[i]);
             }
-            printf("\n");
+            // printf("\n");
             for(int i = 0; i < blf->nb_divisions; i++) {
               double L = hWall * t[i] / t[0];
               SPoint2 pnew(par.x() + L * n.x(), par.y() + L * n.y());
